@@ -1,4 +1,4 @@
-from typing import Any, List
+from typing import Any, List, Union
 
 from pydantic import BaseModel
 from pydantic.fields import ModelField
@@ -41,21 +41,21 @@ class BeanieDocumentFactory(ModelFactory[Document]):
     @classmethod
     def is_ignored_type(cls, value: Any) -> bool:
         """
-        Overriden to exclude PydanticObjectId
+        Overridden to exclude PydanticObjectId
 
         """
         return super().is_ignored_type(value=value) or value is PydanticObjectId
 
     @classmethod
-    def get_field_value(cls, model_field: ModelField) -> Any:
+    def get_field_value(cls, model_field: ModelField, field_parameters: Union[dict, list, None] = None) -> Any:
         """
         Override to handle the fields created by the beanie Indexed helper function
 
         Note: these fields do not have a class we can use, rather they instantiate a private class inside a closure.
-        Hence the hacky solution of checking the __name__ property
+        Hence, the hacky solution of checking the __name__ property
         """
         if hasattr(model_field.type_, "__name__") and "Indexed " in model_field.type_.__name__:
             base_type = model_field.outer_type_.__bases__[0]
             model_field.outer_type_ = base_type
             model_field.type_ = base_type
-        return super().get_field_value(model_field=model_field)
+        return super().get_field_value(model_field=model_field, field_parameters=field_parameters)
