@@ -25,6 +25,7 @@ from typing import (
     ItemsView,
     List,
     Optional,
+    Type,
     TypeVar,
     Union,
     cast,
@@ -77,7 +78,7 @@ from pydantic import (
 )
 from pydantic.color import Color
 from pydantic.fields import ModelField
-from typing_extensions import Type, get_args
+from typing_extensions import get_args
 
 from pydantic_factories.constraints.constrained_collection_handler import (
     handle_constrained_collection,
@@ -148,14 +149,16 @@ class ModelFactory(ABC, Generic[T]):
     __sync_persistence__: Optional[Union[Type[SyncPersistenceProtocol[T]], SyncPersistenceProtocol[T]]] = None
     __async_persistence__: Optional[Union[Type[AsyncPersistenceProtocol[T]], AsyncPersistenceProtocol[T]]] = None
     __allow_none_optionals__: bool = True
+    __random_seed__: Optional[int] = None
 
     @classmethod
     def seed_random(cls, seed: int) -> None:
         """
         Seeds Fake and random methods with seed
         """
-        random.seed(seed)
+        random.seed(seed, version=3)
         Faker.seed(seed)
+        cls.__random_seed__ = seed
 
     @classmethod
     def is_model_factory(cls, value: Any) -> bool:
@@ -363,7 +366,9 @@ class ModelFactory(ABC, Generic[T]):
             if issubclass(outer_type, ConstrainedDecimal):
                 return handle_constrained_decimal(field=cast(ConstrainedDecimal, outer_type))
             if issubclass(outer_type, ConstrainedStr):
-                return handle_constrained_string(field=cast(ConstrainedStr, outer_type))
+                return handle_constrained_string(
+                    field=cast(ConstrainedStr, outer_type), random_seed=cls.__random_seed__
+                )
             if issubclass(outer_type, ConstrainedBytes):
                 return handle_constrained_bytes(field=cast(ConstrainedBytes, outer_type))
             if issubclass(outer_type, (ConstrainedSet, ConstrainedList)) or (
@@ -386,18 +391,17 @@ class ModelFactory(ABC, Generic[T]):
         return random.choice(list(outer_type))
 
     @classmethod
-    def handle_factory_field(cls, field_name: str) -> Any:
+    def handle_factory_field(cls, field_value: Any) -> Any:
         """Handles a field defined on the factory class itself"""
         from pydantic_factories.fields import Use
 
-        value = getattr(cls, field_name)
-        if isinstance(value, Use):
-            return value.to_value()
-        if cls.is_model_factory(value):
-            return cast(ModelFactory, value).build()
-        if callable(value):
-            return value()
-        return value
+        if isinstance(field_value, Use):
+            return field_value.to_value()
+        if cls.is_model_factory(field_value):
+            return cast(ModelFactory, field_value).build()
+        if callable(field_value):
+            return field_value()
+        return field_value
 
     @classmethod
     def create_factory(
@@ -412,6 +416,7 @@ class ModelFactory(ABC, Generic[T]):
         kwargs.setdefault("__sync_persistence__", cls.__sync_persistence__)
         kwargs.setdefault("__async_persistence__", cls.__async_persistence__)
         kwargs.setdefault("__allow_none_optionals__", cls.__allow_none_optionals__)
+        kwargs.setdefault("__random__seed__", cls.__random_seed__)
         return cast(
             ModelFactory,
             type(
@@ -422,7 +427,7 @@ class ModelFactory(ABC, Generic[T]):
         )
 
     @classmethod
-    def get_field_value(cls, model_field: ModelField) -> Any:
+    def get_field_value(cls, model_field: ModelField, field_parameters: Union[dict, list, None] = None) -> Any:
         """
         Returns a field value on the subclass if existing, otherwise returns a mock value
         """
@@ -434,13 +439,19 @@ class ModelFactory(ABC, Generic[T]):
         if isinstance(outer_type, EnumMeta):
             return cls.handle_enum(outer_type)
         if is_pydantic_model(outer_type) or is_dataclass(outer_type):
-            return cls.create_factory(model=outer_type).build()
+            build_kwargs: dict = field_parameters or {}  # type: ignore
+            return cls.create_factory(model=outer_type).build(**build_kwargs)
+        if isinstance(field_parameters, list) and is_pydantic_model(model_field.type_):
+            return [
+                cls.create_factory(model=model_field.type_).build(**build_kwargs) for build_kwargs in field_parameters
+            ]
         if cls.is_constrained_field(outer_type):
             return cls.handle_constrained_field(model_field=model_field)
         if model_field.sub_fields:
             return handle_complex_type(model_field=model_field, model_factory=cls)
         if is_literal(model_field):
-            return get_args(outer_type)[0]
+            literal_args = get_args(outer_type)
+            return random.choice(literal_args)
         # this is a workaround for the following issue: https://github.com/samuelcolvin/pydantic/issues/3415
         field_type = model_field.type_ if model_field.type_ is not Any else outer_type
         if cls.is_ignored_type(field_type):
@@ -459,11 +470,47 @@ class ModelFactory(ABC, Generic[T]):
         return False
 
     @classmethod
-    def should_set_field_value(cls, field_name: str, **kwargs: Any) -> bool:
+    def _is_kwargs_missing_pydantic_fields(cls, pydantic_model: Type[T], pydantic_model_kwargs: Any) -> bool:
+        """
+        Determines if the kwargs are missing fields that should be defined in the pydantic model.
+
+        Returns False if all fields of the pydantic model are defined in the kwargs, and True otherwise.
+        """
+        if is_pydantic_model(pydantic_model_kwargs.__class__):
+            return False
+        pydantic_model_fields = cls.get_model_fields(pydantic_model)
+        pydantic_model_field_names = set(dict(pydantic_model_fields).keys())
+        kwargs_field_names = set(pydantic_model_kwargs.keys())
+        return bool(pydantic_model_field_names - kwargs_field_names)
+
+    @classmethod
+    def _is_pydantic_with_partial_fields(cls, field_name: str, model_field: ModelField, **kwargs: Any) -> bool:
+        """
+        Determines if the field is a pydantic model AND if the kwargs are missing fields that should be defined in the pydantic model
+
+        Returns False if model_field isn't a Pydantic model OR if all fields of the pydantic model are defined in the kwargs, and True otherwise.
+        """
+        pydantic_model = model_field.type_
+        if not is_pydantic_model(pydantic_model):
+            return False
+
+        list_of_pydantic_models_kwargs = kwargs[field_name]
+        if not isinstance(list_of_pydantic_models_kwargs, list) and cls._is_kwargs_missing_pydantic_fields(
+            pydantic_model, list_of_pydantic_models_kwargs
+        ):
+            return True
+
+        return any(
+            cls._is_kwargs_missing_pydantic_fields(pydantic_model, pydantic_model_kwargs)
+            for pydantic_model_kwargs in list_of_pydantic_models_kwargs
+        )
+
+    @classmethod
+    def should_set_field_value(cls, field_name: str, model_field: ModelField, **kwargs: Dict[str, Any]) -> bool:
         """
         Ascertain whether to set a value for a given field_name
 
-        Separated to its own method to allow black-listing field names in sub-classes
+        Separated to its own method to allow black-listing field names in subclasses
         """
         is_field_ignored = False
         is_field_in_kwargs = field_name in kwargs
@@ -472,14 +519,16 @@ class ModelFactory(ABC, Generic[T]):
             if isinstance(value, Require) and not is_field_in_kwargs:
                 raise MissingBuildKwargError(f"Require kwarg {field_name} is missing")
             is_field_ignored = isinstance(value, Ignore)
-        return not is_field_ignored and not is_field_in_kwargs
+        return not is_field_ignored and (
+            not is_field_in_kwargs or cls._is_pydantic_with_partial_fields(field_name, model_field, **kwargs)
+        )
 
     @classmethod
     def get_model_fields(cls, model: Type[T]) -> ItemsView[str, ModelField]:
         """
         A function to retrieve the fields of a given model.
 
-        If the model passed is a dataclass, its converted to a pydantic model first.
+        If the model passed is a dataclass, it's converted to a pydantic model first.
         """
         if not is_pydantic_model(model):
             model = create_model_from_dataclass(dataclass=model)  # type: ignore
@@ -495,16 +544,25 @@ class ModelFactory(ABC, Generic[T]):
 
         Note - this is supported only for pydantic models
         """
+        from pydantic_factories.fields import PostGenerated
+
+        generate_post: Dict[str, PostGenerated] = {}
+
         model = cls._get_model()
         for field_name, model_field in cls.get_model_fields(model):
             if cls.should_use_alias_name(model_field, model):
                 field_name = model_field.alias
-
-            if cls.should_set_field_value(field_name, **kwargs):
+            if cls.should_set_field_value(field_name, model_field, **kwargs):
                 if hasattr(cls, field_name):
-                    kwargs[field_name] = cls.handle_factory_field(field_name=field_name)
+                    value = getattr(cls, field_name)
+                    if isinstance(value, PostGenerated):
+                        generate_post[field_name] = value
+                    else:
+                        kwargs[field_name] = cls.handle_factory_field(field_value=value)
                 else:
-                    kwargs[field_name] = cls.get_field_value(model_field=model_field)
+                    kwargs[field_name] = cls.get_field_value(model_field, field_parameters=kwargs.get(field_name, {}))
+        for field_name, post_generator in generate_post.items():
+            kwargs[field_name] = post_generator.to_value(field_name, kwargs)
         if factory_use_construct:
             if is_pydantic_model(cls.__model__):
                 return cls.__model__.construct(**kwargs)  # type: ignore
